<?php
/**
 * This file handles the admin area and functions.
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */

/************* ADMIN NOTICE *****************/
function leapin_get_admin_notices()
{
    $ret = [
        'learn-initial-setup' => [
            'frequency' => 'once',
            'level' => 'info',
            'disp-in-pro' => true,
            'message' => sprintf(__('Make a website like <a href=%s target="_blank">this demo</a> in 5 mins. Start from <a href=%s target="_blank">here</a>.', 'pjax-blog'), esc_url('https://demo.leap-in.com/pjax-blog-free/'), esc_url('https://leap-in.com/installation/'))
        ],
        'learn-more' => [
            'frequency' => 'every-login',
            'level' => 'info',
            'disp-in-pro' => true,
            'message' => sprintf(__('Learn Pjax Blog More. <a href=%s target="_blank">Website</a> | <a href=%s target="_blank">Documents</a>.', 'pjax-blog'), esc_url('https://leap-in.com/'), esc_url('https://leap-in.com/documents/'))
        ],
        'upgrade' => [
            'frequency' => 'every-login',
            'level' => 'info',
            'disp-in-pro' => false,
            'message' => sprintf(__('Upgrade to <a class="button button-primary" href=%s target="_blank">Pjax Blog Pro</a> to unlock <a href=%s target="_blank">More Features</a>!', 'pjax-blog'), esc_url('https://leap-in.com/'), esc_url('https://leap-in.com/category/features/'))
        ]
    ];
    if(!leapin_is_bundle()){
        $ret['install-bundle'] = [
            'frequency' => 'every-login',
            'level' => 'warning',
            'disp-in-pro' => false,
            'message' => sprintf(__('Please install free plugin <a href=%s target="_blank">Pjax Blog Bundle</a>! Make your site faster and powerful:)', 'pjax-blog'), esc_url('https://leap-in.com/plugin-pjax-blog-bundle/'))
        ];
    }else{
        if(!leapin_is_compatible_bundle_ver(LEAPIN_CAPABLE_BUNDLE, '>=')){
            $ret['install-bundle-upgrade'] = [
                'frequency' => 'every-login',
                'level' => 'error',
                'disp-in-pro' => true,
                'message' => sprintf(__('Please update <a href=%s target="_blank">Pjax Blog Bundle</a> to v%s.', 'pjax-blog'), esc_url('https://leap-in.com/plugin-pjax-blog-bundle/'), LEAPIN_CAPABLE_BUNDLE)
            ];
        }
    }
    return $ret;
}

function leapin_add_document_url_to_admin_panel()
{
    $messages = leapin_get_admin_notices();
    // Only show this message on the admin dashboard and if asked for
    foreach ($messages as $id => $message) {
        leapin_the_dismissable_message($id, $message);
    }
}

add_action('admin_notices', 'leapin_add_document_url_to_admin_panel');


/**
 * Register dismissal of admin notices.
 *
 * Acts on the dismiss link in the admin nag messages.
 * If clicked, the admin notice disappears and will no longer be visible to this user until next login.
 *
 * @since 1.6.10
 */
function leapin_dismiss_notice()
{
    if (isset($_GET['leapin-dismiss']) && check_admin_referer('leapin-dismiss-' . get_current_user_id())) {
        update_user_meta(get_current_user_id(), 'leapin_dismissed_notice-' . esc_attr($_GET['leapin-dismiss']), 1);
    }
}

add_action('admin_head', 'leapin_dismiss_notice');
/**
 * Delete dismissable nag option when user login.
 *
 * This ensures that the user(s) is/are again reminded via nag of required
 * and/or recommended plugins if they re-activate the theme.
 *
 * @since 1.6.10
 */
function leapin_reset_dismiss_notice()
{
    $messages = leapin_get_admin_notices();
    foreach ($messages as $id => $val) {
        if($val['frequency'] === 'every-login'){
            delete_metadata('user', null, 'leapin_dismissed_notice-' . $id, null, true);
        }
    }
}

add_action('wp_login', 'leapin_reset_dismiss_notice');

function leapin_the_dismissable_message($id, $message)
{
    $dismiss_endpoint = esc_url(wp_nonce_url(add_query_arg('leapin-dismiss', $id), 'leapin-dismiss-' . get_current_user_id()));
    $ms = $message['message'];
    $level = $message['level'];
    $disp_in_pro = $message['disp-in-pro'];
    if (!($disp_in_pro === false && leapin_is_pro())):
        if (!get_user_meta(get_current_user_id(), 'leapin_dismissed_notice-' . $id, 1)):
            ?>
            <div class="leapin notice notice-<?php echo $level; ?> is-dismissible"
                 data-dismiss-url="<?php echo $dismiss_endpoint; ?>">
                <p><?php echo $ms; ?></p>
            </div>
        <?php endif;
    endif;
}

function leapin_admin_wp_alpha_color_picker_field($id, $class = "", $name, $value, $show_opacity = 'true')
{
    printf(
        '<input id="%s" type="text" class="color-picker %s" name="%s" value="%s" data-alpha="%s" />',
        esc_attr($id),
        esc_attr($class),
        esc_attr($name),
        esc_attr($value),
        esc_attr($show_opacity)
    );
}


/**
 * Add custom checkbox field to widget
 *
 * @since 1.7.2
 * @param $widget_object
 * @param $instance
 * @param $field_id
 * @param $args
 *        label - input label
 */
function leapin_add_checkbox_to_widget_form($widget_object, $instance, $field_id, $args)
{
    if (!isset($args)) return;
    $label = array_key_exists('label', $args) ? $args['label'] : '';
    ?>
    <p>
        <input id="<?php echo $widget_object->get_field_id($field_id); ?>"
               name="<?php echo $widget_object->get_field_name($field_id); ?>"
               type="checkbox" <?php checked(isset($instance[$field_id]) ? $instance[$field_id] : 0); ?> />
        <label for="<?php echo $widget_object->get_field_id($field_id); ?>"><?php echo $label ?></label>
    </p>
    <?php
}

/**
 * Add custom number field to widget
 *
 * @since 1.7.2
 * @param $widget_object
 * @param $instance
 * @param $field_id widget field id
 * @param $args
 *        label - input label
 *        default - default value
 *        min - min number
 *        max - max number
 */
function leapin_add_number_to_widget_form($widget_object, $instance, $field_id, $args)
{
    if (!isset($args)) return;
    $label = array_key_exists('label', $args) ? $args['label'] : '';
    $default = array_key_exists('default', $args) ? $args['default'] : '';
    $min = array_key_exists('min', $args) ? sprintf(' min="%s"', $args['min']) : '';
    $max = array_key_exists('max', $args) ? sprintf(' max="%s"', $args['max']) : '';
    $current = isset($instance[$field_id]) || (array_key_exists($field_id, $instance) && $instance[$field_id] === 0)
        ? esc_attr($instance[$field_id]) : $default;
    ?>
    <p>
        <label for="<?php echo $widget_object->get_field_id($field_id); ?>"><?php echo $label; ?></label>
        <input class="tiny-text" id="<?php echo $widget_object->get_field_id($field_id); ?>"
               name="<?php echo $widget_object->get_field_name($field_id); ?>"<?php echo $min . $max; ?>
               type="number" value="<?php echo $current; ?>"/>
    </p>
    <?php
}

function leapin_add_text_to_widget_form($widget_object, $instance, $field_id, $args)
{
    if (!isset($args)) return;
    $label = array_key_exists('label', $args) ? $args['label'] : '';
    $default = array_key_exists('default', $args) ? $args['default'] : '';
    $current = isset($instance[$field_id]) || (array_key_exists($field_id, $instance) && $instance[$field_id] === 0)
        ? esc_attr($instance[$field_id]) : $default;
    ?>
    <p><label for="<?php echo $widget_object->get_field_id($field_id); ?>"><?php echo $label; ?></label>
        <input class="widefat" id="<?php echo $widget_object->get_field_id($field_id); ?>"
               name="<?php echo $widget_object->get_field_name($field_id); ?>" type="text"
               value="<?php echo $current; ?>"/>
    </p>
    <?php
}

function leapin_add_color_picker_to_widget_form($widget_object, $instance, $field_id, $args)
{
    if (!isset($args)) return;
    $label = array_key_exists('label', $args) ? $args['label'] : '';
    $default = array_key_exists('default', $args) ? $args['default'] : '';
    $show_opacity = array_key_exists('show_opacity', $args) && !empty($args['show_opacity']) ? "true" : "";
    $current = isset($instance[$field_id]) || (array_key_exists($field_id, $instance) && $instance[$field_id] === 0)
        ? esc_attr($instance[$field_id]) : $default;
    ?>
    <p>
        <label for="<?php echo $widget_object->get_field_id($field_id); ?>"
               style="display:block;"><?php echo $label; ?></label>
        <?php
        leapin_admin_wp_alpha_color_picker_field(
            $widget_object->get_field_id($field_id),
            "",
            $widget_object->get_field_name($field_id),
            $current,
            $show_opacity
        );
        ?>
    </p>
    <?php
}

function leapin_add_textarea_to_widget_form($widget_object, $instance, $field_id, $args)
{
    if (!isset($args)) return;
    $label = array_key_exists('label', $args) ? $args['label'] : '';
    $default = array_key_exists('default', $args) ? $args['default'] : '';
    $current = isset($instance[$field_id]) || (array_key_exists($field_id, $instance) && $instance[$field_id] === 0)
        ? esc_attr($instance[$field_id]) : $default;
    ?>
    <p>
        <label for="<?php echo $widget_object->get_field_id($field_id); ?>"><?php echo $label; ?></label>
        <textarea class="widefat" id="<?php echo $widget_object->get_field_id($field_id); ?>"
                  name="<?php echo $widget_object->get_field_name($field_id); ?>"><?php echo $current; ?></textarea>
    </p>
    <?php
}

function leapin_add_large_title_to_widget_form($title)
{
    ?>
    <p style="font-weight: 600;margin-top: 20px;font-size: 21px;"><?php echo $title; ?></p>
    <?php
}

/**
 * Add custom select field to widget
 *
 * @since 1.7.2
 * @param $widget_object
 * @param $instance
 * @param $field_id
 * @param $args
 *        label - select label
 *        default - default value
 *        choice - options ['value' => 'label']
 */
function leapin_add_select_to_widget_form($widget_object, $instance, $field_id, $args)
{
    if (!isset($args)) return;
    $label = array_key_exists('label', $args) ? $args['label'] : '';
    $default = array_key_exists('default', $args) ? $args['default'] : '';
    $choice = array_key_exists('choice', $args) && is_array($args['choice']) ? $args['choice'] : [];
    $current = isset($instance[$field_id]) ? $instance[$field_id] : $default;
    printf(
        '<p><label for="%1$s">%2$s</label><select class="widefat" id="%1$s" name="%3$s">',
        $widget_object->get_field_id($field_id),
        $label,
        $widget_object->get_field_name($field_id)
    );

    foreach ($choice as $value => $option_name) {
        printf(
            '<option value="%s"%s>%s</option>',
            esc_attr($value),
            selected($value, $current, false),
            $option_name
        );
    }
    echo '</select></p>';
}
/**
 * @todo implement in latter version
 */
//function leapin_get_tax_color($tax_id_or_slug)
//{
//    global $leapin_vars;
//    $taxonomies = $leapin_vars['taxonomies'];
//    if (is_numeric($tax_id_or_slug)) {
//        $t_id = $tax_id_or_slug;
//
//    } else {
//        if (array_key_exists($tax_id_or_slug, $taxonomies)) {
//            $t_id = $taxonomies[$tax_id_or_slug]->ID;
//        }
//    }
//
//    // Get the custom fields based on the $presenter term ID
//    $custom_fields = get_option("taxonomy_term_$t_id");
//
//    // Return the value for the "presenter_id" custom field
//    $tax_color = $custom_fields['tax_color'];
//
//    return $tax_color ? $tax_color : false;
//}

//function leapin_all_tax_color()
//{
//    global $leapin_vars;
//    $taxonomies = $leapin_vars['taxonomies'];
//
//    $tax_terms = [];
//    foreach ($taxonomies as $tax => $tax_value) {
//        $terms = get_terms(['taxonomy' => $tax, 'hide_empty' => false,]);
//        foreach ($terms as $term) {
//            $t_id = $term->term_id;
//            // Get the custom fields based on the $presenter term ID
//            $custom_fields = get_option("taxonomy_term_$t_id");
//
//            // Return the value for the "presenter_id" custom field
//            $tax_color = $custom_fields['tax_color'];
//
//            $tax_color = $tax_color ? $tax_color : false;
//            if ($tax_color) {
//                $tax_terms[$term->term_id] = $tax_color;
//            }
//        }
//    }
//    return $tax_terms;
//}

?>
